"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pluginFinder = exports.loadPluginFolder = void 0;
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("node:fs"));
const path = tslib_1.__importStar(require("node:path"));
/**
 * The method that loads plugin files from a directory
 * @param basedir The base plugin directory
 * @param folder The plugin folder
 */
async function loadPluginFolder(basedir, folder) {
    if (folder.isDirectory()) {
        if (fs.existsSync(path.join(basedir, folder.name, 'index.js'))) {
            await Promise.resolve().then(() => tslib_1.__importStar(require(path.join(basedir, folder.name, 'index.js'))));
        }
        else if (fs.existsSync(path.join(basedir, folder.name, 'register.js'))) {
            await Promise.resolve().then(() => tslib_1.__importStar(require(path.join(basedir, folder.name, 'register.js'))));
        }
        else if (fs.existsSync(path.join(basedir, folder.name, 'dist', 'index.js'))) {
            await Promise.resolve().then(() => tslib_1.__importStar(require(path.join(basedir, folder.name, 'dist', 'index.js'))));
        }
        else if (fs.existsSync(path.join(basedir, folder.name, 'dist', 'register.js'))) {
            await Promise.resolve().then(() => tslib_1.__importStar(require(path.join(basedir, folder.name, 'dist', 'register.js'))));
        }
    }
}
exports.loadPluginFolder = loadPluginFolder;
/**
 * The method that find all plugins in a directory
 * @param {string} basedir The directory to find plugins in
 */
async function pluginFinder(basedir) {
    if (fs.existsSync(basedir)) {
        if (fs.existsSync(path.join(basedir, 'plugins'))) {
            for await (const folder of fs.readdirSync(path.join(basedir, 'plugins'), {
                withFileTypes: true,
            })) {
                await loadPluginFolder(path.join(basedir, 'plugins'), folder);
            }
        }
        if (fs.existsSync(path.join(basedir, 'src', 'plugins'))) {
            for await (const folder of fs.readdirSync(path.join(basedir, 'src', 'plugins'), { withFileTypes: true })) {
                await loadPluginFolder(path.join(basedir, 'src', 'plugins'), folder);
            }
        }
        if (fs.existsSync(path.join(basedir, 'node_modules'))) {
            for await (const folder of fs.readdirSync(path.join(basedir, 'node_modules'), { withFileTypes: true })) {
                if (!folder.name.includes('gcommands-plugin-'))
                    continue;
                await loadPluginFolder(path.join(basedir, 'node_modules'), folder);
            }
        }
        if (fs.existsSync(path.join(basedir, 'node_modules', '@gcommands'))) {
            for await (const folder of fs.readdirSync(path.join(basedir, 'node_modules', '@gcommands'), {
                withFileTypes: true,
            })) {
                if (!folder.name.includes('plugin-'))
                    continue;
                await loadPluginFolder(path.join(basedir, 'node_modules', '@gcommands'), folder);
            }
        }
    }
}
exports.pluginFinder = pluginFinder;
