"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Plugin = void 0;
const zod_1 = require("zod");
const PluginManager_1 = require("../managers/PluginManager");
const Logger_1 = require("../util/logger/Logger");
const validationSchema = zod_1.z
    .object({
    name: zod_1.z.string(),
    run: zod_1.z.function(),
})
    .passthrough();
class Plugin {
    constructor(name, run) {
        validationSchema
            .parseAsync({ name, run, ...this })
            .then(options => {
            this.name = options.name;
            this.run = options.run;
            // @ts-expect-error Zod :))
            this.options = options;
            PluginManager_1.Plugins.register(this);
        })
            .catch(error => {
            Logger_1.Logger.warn(typeof error.code !== 'undefined' ? error.code : '', error.message);
            if (error.stack)
                Logger_1.Logger.trace(error.stack);
        });
    }
}
exports.Plugin = Plugin;
